def F(*_):
  return False
